﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Caching.Memory;
using Newtonsoft.Json;
using Sugar.Enties;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq.Expressions;
using System.Net.Http;
using WebAPIBase.Utils;

namespace WebAPIBase.API.Controllers
{
    [Produces("application/json;charset=UTF-8")]
    [Route("api/Common")]
    [ServiceFilter(typeof(Filter.TokenAuthorize))]
    public class CommonController : BaseController
    {
        /// <summary>
        /// 存储模式  file:文件  ，database：数据库
        /// </summary>
        private string savePattern = new ConfigItemValueManager().AttachmentSavePattern;
        /// <summary>
        /// 文件存储目录
        /// </summary>
        private string savePath = new ConfigItemValueManager().AttachmentSavePath;
        /// <summary>
        /// 文件目录模式
        /// </summary>
        private string pathPattern = new ConfigItemValueManager().AttachmentPathPattern;

        public CommonController(IMemoryCache memoryCache, IHttpClientFactory httpclientfactory)
            : base()
        {


        }

        /// <summary>
        /// 获取部门用户
        /// </summary>
        /// <param name="projectid"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet]
        [Route("GetUnitUser")]
        public ActionResult GetUnitUser(string projectid)
        {
            var unitManager = new UnitManager();
            var tree = unitManager.GetUnitUser(projectid);
            var list = new List<TreeDTO>();
            list.Add(tree);
            logger.Info($"【getunituser】{JsonConvert.SerializeObject(list)}");
            return Json(list);
        }

        /// <summary>
        /// 获取部门信息
        /// </summary>
        /// <param name="projectid"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet]
        [Route("GetUnit")]
        public ActionResult GetUnit(string projectid)
        {
            var unitManager = new UnitManager();
            var tree = unitManager.GetUnit(projectid);
            var list = new List<TreeDTO>();
            list.Add(tree);
            logger.Info($"【GetUnit】{JsonConvert.SerializeObject(list)}");
            return Json(list);
        }
        /// <summary>
        /// 根据用户代码获取用户所属部门
        /// </summary>
        /// <param name="usercode"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet]
        [Route("GetUserDepartment")]
        public ActionResult GetUserDepartment(string usercode)
        {
            var unitManager = new UnitManager();
            var department = unitManager.GetUserDepartment(usercode);

            logger.Info($"【GetUserDepartment】{department}");
            return Json(department);
        }

        /// <summary>
        /// 获取项目列表
        /// </summary>
        /// <returns></returns>
        //[AllowAnonymous]
        [HttpGet]
        [Route("GetProjectList")]
        public JsonResult GetProjectList()
        {
            var res = new ApiResponse
            {
                IsSuccess = false,
                Code = 0,
                ErrMsg = ""
            };
            var unitManager = new UnitManager();
            var list = unitManager.GetProjectList();

            logger.Info($"【GetProjectList】{JsonConvert.SerializeObject(list)}");
            res.IsSuccess = true;
            res.ErrMsg = "";
            res.Data = list;
            return Json(res);
        }

        /// <summary>
        /// /图片上传
        /// </summary>
        /// <param name="formCollection"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpPost]
        [DisableRequestSizeLimit]      //禁用大小限制
        [Route("UploadImage")]
        public ActionResult UploadImage([FromForm] IFormCollection formCollection)
        {
            var list = new List<AttachMent>();
            //logger.Info(Request.Body);
            var createPerson = Request.Form["createPerson"].ToString();
            var masterCode = Request.Form["masterCode"].ToString();
            var attachMentType = Request.Form["attachMentType"].ToString();
            //logger.Info(Request.Form["masterCode"]);
            FormFileCollection filelist = (FormFileCollection)formCollection.Files;
            //logger.Info(JsonConvert.SerializeObject(filelist));
            var manager = new AttachMentManager();
            if (savePattern == "file")    //文件存储到文件目录下
            {
                foreach (IFormFile file in filelist)
                {
                    //保存到数据库
                    var attachMent = new AttachMent();
                    attachMent.FileName = file.FileName;
                    attachMent.Content_Type = file.ContentType;
                    attachMent.Length = (int?)file.Length;
                    attachMent.GuidName = Guid.NewGuid().ToString();
                    attachMent.AttachMentType = attachMentType;
                    attachMent.CreatePerson = createPerson;
                    attachMent.MasterCode = masterCode;
                    manager.AddOrUpdate(attachMent);
                    #region 存文件到文件夹
                    var filePath = savePath;
                    var filename = attachMent.GuidName;
                    //获取日期路径
                    var creatDate = DateTime.Now.ToString("yyyyMMDD");
                    if (pathPattern == "Root")
                    {

                    }
                    else if (pathPattern == "YYYY")
                    {
                        filePath += $"/{creatDate.Substring(0, 4)}";
                    }
                    else if (pathPattern == "YYYYMM")
                    {
                        filePath += $"/{creatDate.Substring(0, 6)}";
                    }
                    else if (pathPattern == "YYYYMMDD")
                    {
                        filePath += $"/{creatDate}";
                    }
                    if (!Directory.Exists(filePath))    //若文件目录不存在，则创建目录
                    {
                        Directory.CreateDirectory(filePath);
                    }
                    filePath += $"/{filename}";
                    using (var sw = System.IO.File.Open(filePath, FileMode.Create, FileAccess.Write))
                    {
                        var stream = file.OpenReadStream();
                        var content = Utils.UploadFileHelper.StreamToBytes(stream);
                        sw.Write(content, 0, content.Length);
                        sw.Close();
                    }
                    #endregion

                }
            }
            else                  //文件存储到数据库
            {
                foreach (IFormFile file in filelist)
                {
                    var attachMent = new AttachMent();
                    attachMent.FileName = file.FileName;
                    attachMent.Content_Type = file.ContentType;
                    attachMent.Length = (int?)file.Length;
                    var stream = file.OpenReadStream();
                    attachMent.Content = Utils.UploadFileHelper.StreamToBytes(stream);
                    attachMent.AttachMentType = attachMentType;
                    attachMent.CreatePerson = createPerson;
                    attachMent.MasterCode = masterCode;
                    manager.AddOrUpdate(attachMent);
                }
            }


            return Json("success");
        }

        /// <summary>
        /// 附件显示
        /// </summary>
        /// <param name="code"></param>
        /// <returns></returns>
        [AllowAnonymous]
        [HttpGet]
        [Route("ShowImg")]
        public FileResult ShowImg(string code)
        {
            var bll = new AttachMentManager();
            var entity = bll.GetAttachMent(code);
            if (entity.Content != null)     //从数据库读取
            {
                return File(entity.Content, entity.Content_Type);
            }
            else                           //从路径读取
            {
                var filePath = savePath;
                var filename = entity.GuidName;
                //获取日期路径
                var creatDate = entity.CreateDate.Value.ToString("yyyyMMDD");
                if (pathPattern == "Root")
                {
                    filePath += $"/{filename}";
                }
                else if (pathPattern == "YYYY")
                {
                    filePath += $"/{creatDate.Substring(0, 4)}/{filename}";
                }
                else if (pathPattern == "YYYYMM")
                {
                    filePath += $"/{creatDate.Substring(0, 6)}/{filename}";
                }
                else if (pathPattern == "YYYYMMDD")
                {
                    filePath += $"/{creatDate}/{filename}";
                }
                logger.Info($"附件保存路径：{filePath}");
                if (!System.IO.File.Exists(filePath))
                {
                    RedirectToAction("NotFound");
                }
                FileStream fs = new FileStream(filePath, FileMode.Open, FileAccess.Read);
                byte[] infbytes = new byte[(int)fs.Length];
                fs.Read(infbytes, 0, infbytes.Length);
                fs.Close();
                var contentType = entity.Content_Type;
                return File(infbytes, contentType);
            }


        }
        //[HttpGet]
        //[Route("NotFound")]
        //public override NotFoundResult NotFound()
        //{
        //    return base.NotFound();
        //}

        /// <summary>
        /// 获取父子权限的数据列表
        /// </summary>
        /// <param name="classCode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetMaterialTree")]
        public ActionResult GetMaterialTree(string classCode)
        {
            var manager = new UnitManager();
            var list = manager.GetMaterial(classCode);
            return Json(list);
        }
        /// <summary>
        /// 根据功能模块代码返回有权限的岗位代码和用户代码列表
        /// </summary>
        /// <param name="functionStructureCode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetUserFunctions")]
        public ActionResult GetUserFunctions(string functionStructureCode)
        {
            var manager = new RoleManager();
            var list = manager.GetUserFunctions(functionStructureCode);
            return Json(list);
        }
        /// <summary>
        /// 根据功能模块代码和用户代码返回用户权限实例
        /// </summary>
        /// <param name="functionStructureCode"></param>
        /// <param name="usercode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetUserFunction")]
        public ActionResult GetUserFunction(string functionStructureCode, string usercode)
        {
            var manager = new RoleManager();
            var entity = manager.GetUserFunction(functionStructureCode, usercode);
            return Json(entity);
        }

        /// <summary>
        /// 根据项目代码获取材料合同
        /// </summary>
        /// <param name="projectcode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetContracts")]
        public ActionResult GetContracts(string projectcode, string searchValue)
        {
            var manager = new UnitManager();
            var list = manager.GetContracts(projectcode, searchValue);
            return Json(list);
        }
        /// <summary>
        /// 根据合同单号获取合同实体
        /// </summary>
        /// <param name="contractCode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetContract")]
        public ActionResult GetContract(string contractCode)
        {
            var manager = new UnitManager();
            var model = manager.GetContract(contractCode);
            return Json(model);
        }
        /// <summary>
        /// 根据项目代码获取工程合同
        /// </summary>
        /// <param name="projectcode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetEngineeringContracts")]
        public ActionResult GetEngineeringContracts(string projectcode, string searchValue)
        {
            var manager = new UnitManager();
            Expression<Func<Contract, bool>> lambda = m => m.ProjectCode == projectcode && m.contracttype == "工程合同" && (m.Status == 0 || m.Status == 2);
            if (!string.IsNullOrEmpty(searchValue))
            {
                lambda = lambda.And(m => m.ContractID.Contains(searchValue) || m.ContractName.Contains(searchValue));

            }
            var list = manager.GetContracts(lambda);
            return Json(list);
        }
        /// <summary>
        /// 获取供应商名称和类型
        /// </summary>
        /// <param name="supplierCode"></param>
        /// <param name="SupplierTypeCode"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetSupplierNameAndType")]
        public ActionResult GetSupplierNameAndType(string supplierCode, string SupplierTypeCode)
        {
            var manager = new MaterialInManager();
            var str = manager.GetSupplierNameAndType(supplierCode, SupplierTypeCode);
            return Json(str);
        }

        /// <summary>
        ///  获取质量安全检查项
        /// </summary>
        /// <param name="type">0:质量检查 1：安全检查</param>
        /// <param name="searchvalue"></param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetQualityAndSafeItems")]
        public ActionResult GetQualityAndSafeItems(int type = -1, string searchvalue = "")
        {
            logger.Info($"【GetQualityAndSafeItems】type:{type},searchvalue:{searchvalue}");
            //10034:质量检查项目 10035：安全检查项目
            var manager = new DictionaryNameManager();
            List<DictionaryItem> list;
            Expression<Func<DictionaryItem, bool>> lambda = m => true;
            if (type == 0)
            {
                lambda = lambda.And(m => m.dnCode == "10034");
            }
            else if (type == 1)
            {
                lambda = lambda.And(m => m.dnCode == "10035");
            }
            else if (type == 2)
            {
                lambda = lambda.And(m => m.dnCode == "100130");
            }
            else
            {
                lambda = lambda.And(m => m.dnCode == "10034" || m.dnCode == "10035");
            }
            if (!searchvalue.IsNullOrEmpty())
            {
                lambda = lambda.And(m => m.diName.Contains(searchvalue));
            }


            list = manager.GetDictionaryItems(lambda);

            return Json(list);
        }

        /// <summary>
        /// 查询所有材料
        /// </summary>
        /// <returns></returns>
        [HttpGet]
        [Route("GetMaterialList")]
        public ActionResult GetMaterialList(string name)
        {
            var list = new MaterialManager().GetMaterialList(name);
            return Json(list);
        }
        #region 流程审核
        /// <summary>
        /// 根据流程名，项目编号及是否活动获取可使用的工作流程审核列表
        /// </summary>
        /// <param name="procedureName"></param>
        /// <param name="projectCode"></param>
        /// <param name="activity"></param>
        [HttpGet]
        [Route("GetWorkFlowProcedureList")]
        public ActionResult GetWorkFlowProcedureList(string procedureName, string projectCode, int activity)
        {
            var manager = new WorkFlowProcedureManager();
            var list = manager.GetWorkFlowProcedureList(procedureName, projectCode, activity);
            return Json(list);
        }
        /// <summary>
        /// 流程审核
        /// </summary>
        /// <param name="userCode">用户编码</param>
        /// <param name="procedureCode">流程编码</param>
        /// <returns></returns>
        [HttpGet]
        [Route("WorkFlowAudit")]
        public ActionResult WorkFlowAudit(string userCode, string procedureCode)
        {
            var flowManager = new WorkFlowProcedureManager();
            var taskList = flowManager.GetWorkFlowTasks(procedureCode);
            var isShowHand = false;   //是否显示手送资料
            var isShowUnit = false;   //是否显示经办人部门
            var task = taskList.Find(m => m.TaskName == "申请人");
            isShowHand = task.ModuleState.Contains("Hand") ? true : false;
            isShowUnit = task.ModuleState.Contains("部门") ? true : false;
            var manager = new UnitManager();
            var list = manager.GetUnitDTOList(userCode);
            var data = new
            {
                isShowHand,
                isShowUnit,
                list
            };
            logger.Info($"【WorkFlowAudit】data:{JsonConvert.SerializeObject(data)}");
            return Json(data);
        }

        /// <summary>
        /// 流程保存事件
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [Route("WorkFlowSave")]
        public ActionResult WorkFlowSave([FromBody] WorkFlowDTO dto)
        {
            logger.Info($"【WorkFlowSave】dto:{JsonConvert.SerializeObject(dto)}");
            var actCode = new WorkFlowProcedureManager().WorkFlowSave(dto);

            var returnObject = new ApiResponse();
            if (!actCode.IsInteger())
            {
                returnObject.IsSuccess = false;
                returnObject.ErrMsg = actCode;
            }
            else
            {
                returnObject.IsSuccess = true;
                returnObject.ErrMsg = "";
                returnObject.Data = actCode;
            }
            logger.Info($"【WorkFlowSave】returnObject:{JsonConvert.SerializeObject(returnObject)}");
            return Json(returnObject);
        }
        #endregion


        #region 对接招采平台专用接口

        #region 供应商查询和同步接口
        /// <summary>
        /// 根据供应商编号或供应商名称查询供应商信息
        /// </summary>
        /// <param name="suppliercode">供应商编号或供应商名称</param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetSupplier")]
        [AllowAnonymous]
        public JsonResult GetSupplier(string suppliercode)
        {
            ApiResponse res = new ApiResponse
            {
                IsSuccess = false,
                ErrMsg = "",
                Code = 50,
                TnToken = null
            };
            if (suppliercode.IsNullOrEmpty())
            {
                res.ErrMsg = "请输入供应商编号或供应商名称";
                return Json(res);
            }
            try
            {
                var entity = new SupplierManager().Db.Queryable<Supplier>().Where(m => m.SupplierCode == suppliercode || m.SupplierName == suppliercode).First();
                res.IsSuccess = true;
                res.ErrMsg = "";
                res.Code = 200;
               
                if (entity == null)
                {                   
                    res.Data = null;
                    return Json(res);
                }
                var model = ConvertHelper.ConvertToModel<Supplier, SupplierDTO>(entity);
                res.Data = model;
                return Json(res);
            }
            catch(Exception ex)
            {
                logger.Error(ex);
                res.IsSuccess = false;
                res.ErrMsg = ex.Message;
                res.Code = 500;
                return Json(res);
            }
           
        }

        /// <summary>
        /// 同步供应商信息，同步成功，返回供应商编号，同步失败，返回错误信息
        /// </summary>
        /// <param name="dto">供应商实体</param>
        /// <returns></returns>
        [HttpPost]
        [Route("SyncSupplier")]
        [AllowAnonymous]
        public JsonResult SyncSupplier([FromBody] SupplierDTO dto)
        {
            ApiResponse res = new ApiResponse
            {
                IsSuccess = false,
                ErrMsg="",
                Code=50,
                TnToken = null
            };
            if(dto.SupplierName.IsNullOrEmpty())
            {
                res.ErrMsg = "供应商名称不能为空";
                return Json(res);
            }
            logger.Info($"【SyncSupplier】supplier:{JsonConvert.SerializeObject(dto)}");
            var manager = new SupplierManager();
            try
            {
                manager.Db.BeginTran();
                var model=manager.Db.Queryable<Supplier>().Where(m => m.SupplierName == dto.SupplierName).First();
                if(model==null)  //没有同名的供应商，则插入
                {
                    var code= new UnitManager().GetSysCodeValue("SupplierCode");
                    var supplier = ConvertHelper.ConvertToModel<SupplierDTO, Supplier>(dto);
                    supplier.SupplierCode = code;
                    supplier.InfoCheckCode = code;
                    supplier.Status = 1;
                    if(supplier.ApplyDate.IsNullOrEmpty())
                    {
                        supplier.ApplyDate = DateTime.Now;
                    }
                    var success = manager.Insert(supplier);
                    manager.Db.CommitTran();
                    res.IsSuccess = true;
                    res.ErrMsg = "";
                    res.Code = 200;
                    res.Data = code;
                    return Json(res);
                    
                }
                else      //否则返回供应商编码
                {
                    res.IsSuccess = true;
                    res.ErrMsg = "";
                    res.Code = 200;
                    res.Data = model.SupplierCode;
                    return Json(res);
                }
            }
            catch(Exception ex)
            {
                res.IsSuccess = false;
                res.ErrMsg = $"同步失败，错误信息：{ex.Message}";
                res.Code = 500;
                manager.Db.RollbackTran();
                logger.Error(ex);
                return Json(res);
            }
        }
        #endregion

        #region 中标信息查询同步接口
        /// <summary>
        /// 根据招标编号获取中标信息
        /// </summary>
        /// <param name="biddingcode">oa系统招标编号，地产云系统招标编号</param>
        /// <returns></returns>
        [HttpGet]
        [Route("GetZhongbiao")]
        [AllowAnonymous]
        public JsonResult GetZhongbiao(string biddingcode)
        {
            ApiResponse res = new ApiResponse
            {
                IsSuccess = false,
                ErrMsg = "",
                Code = 50,
                TnToken = null
            };
            if (biddingcode.IsNullOrEmpty())
            {
                res.ErrMsg = "请输入招标编号";
                return Json(res);
            }
            try
            {
                var manager = new BiddingManager();
                var entity = manager.Db.Queryable<Bidding>().Where(m => (m.BiddingCode == biddingcode||m.BiddingId==biddingcode) && m.IsDelegate == 1).First();
                if (entity == null)
                {
                    res.Data = null;
                    res.ErrMsg = "招标记录不存在";
                    return Json(res);
                }
                var detail = manager.Db.Queryable<BiddingDtl>().Where(m => m.BiddingCode == entity.BiddingCode).First();
                res.IsSuccess = true;
                res.ErrMsg = "";
                res.Code = 200;                
                
                var model1 = ConvertHelper.ConvertToModel<Bidding, BiddingDTO>(entity);
                var model2 = ConvertHelper.ConvertToModel<BiddingDtl, BiddingDtlDTO>(detail);
                var model3 = new zhongbiao();
                model3.SupplierCode = entity.SupplierCode;
                model3.Money = detail.Money.Value;
                model3.Title = detail.Title;
                var list1 = new List<BiddingDtlDTO>();
                list1.Add(model2);
                var list2 = new List<zhongbiao>();
                list2.Add(model3);
                model1.BiddingDtlDTO = list1;
                model1.zhongbiao = list2;
                res.Data = model1;
                return Json(res);
            }
            catch (Exception ex)
            {
                res.IsSuccess = false;
                res.ErrMsg = $"{ex.Message}";
                res.Code = 500;                 
                logger.Error(ex);
                return Json(res);
            }
        }

        /// <summary>
        /// 同步中标信息，同步成功，返回招标计划编号串，同步失败，返回错误信息
        /// </summary>
        /// <param name="dto">中标相关信息实体</param>
        /// <returns></returns>
        [HttpPost]
        [Route("SyncZhongbiao")]
        [AllowAnonymous]
        public JsonResult SyncZhongbiao([FromBody] BiddingDTO dto)
        {
            ApiResponse res = new ApiResponse
            {
                IsSuccess = false,
                ErrMsg = "",
                Code = 50,
                TnToken = null
            };
            if (dto.BiddingId.IsNullOrEmpty())
            {
                res.ErrMsg = "招标编号不能为空";
                return Json(res);
            }
            if (dto.BiddingId.Length>100)
            {
                res.ErrMsg = "招标编号不能超过100字";
                return Json(res);
            }
            if (dto.Title.IsNullOrEmpty())
            {
                res.ErrMsg = "拟定标段不能为空";
                return Json(res);
            }
            if (dto.Title.Length > 100)
            {
                res.ErrMsg = "拟定标段不能超过100字";
                return Json(res);
            }
            if(dto.ProjectCode.IsNullOrEmpty())
            {
                res.ErrMsg = "项目编号不能为空";
                return Json(res);
            }
           
            var manager = new BiddingManager();
            var entity = manager.Db.Queryable<Project>().Where(m => m.ProjectCode == dto.ProjectCode).First();
            if(entity==null)
            {
                res.ErrMsg = "项目编号不正确";
                return Json(res);
            }
            foreach (var biddingDtl in dto.BiddingDtlDTO)
            {
                if(biddingDtl.Title.IsNullOrEmpty())
                {
                    res.ErrMsg = "分标段名称不能为空";
                    return Json(res);
                }
                if (biddingDtl.Title.Length>50)
                {
                    res.ErrMsg = "分标段名称不能超过50字";
                    return Json(res);
                }
                if(biddingDtl.Money<=0)
                {
                    res.ErrMsg = "分标段金额不能小于等于0";
                    return Json(res);
                }
            }
            foreach(var item in dto.zhongbiao)
            {
                if(item.SupplierCode.IsNullOrEmpty())
                {
                    res.ErrMsg = "供应商编号不能为空";
                    return Json(res);
                }
                var supplier = manager.Db.Queryable<Supplier>().Where(m => m.SupplierCode == item.SupplierCode).First();
                if(supplier==null)
                {
                    res.ErrMsg = "供应商不存在";
                    return Json(res);
                }
                if(item.Money<=0)
                {
                    res.ErrMsg = "中标金额不能小于等于0";
                    return Json(res);
                }
                if(dto.BiddingDtlDTO.Find(m=>m.Title==item.Title)==null)
                {
                    res.ErrMsg = "中标的分标段名称不正确";
                    return Json(res);
                }
            }
            logger.Info($"【SyncSupplier】BiddingDTO:{JsonConvert.SerializeObject(dto)}");
            
            try
            {
                manager.Db.BeginTran();
                string number = "";
                foreach (var item in dto.zhongbiao)
                {
                    var supplier = manager.Db.Queryable<Supplier>().Where(m => m.SupplierCode == item.SupplierCode).First();
                    var bidding = new Bidding();
                    bidding.BiddingCode = manager.GetSysCodeValue("Bidding");
                    number += bidding.BiddingCode+",";
                    bidding.BiddingId = dto.BiddingId;
                    bidding.Title = dto.Title;
                    bidding.Type = "OA";
                    bidding.ProjectCode = dto.ProjectCode;
                    bidding.State = "2";
                    bidding.Content = dto.Content;
                    bidding.Remark = dto.Remark;
                    bidding.ItemType = "cost";
                    bidding.BiddingRemark1 = "100000";
                    bidding.isDeduct = "0";
                    bidding.Rating = 0;
                    bidding.IsDelegate = 1;
                    bidding.Money = item.Money;
                    bidding.SupplierCode = supplier.SupplierCode;
                    bidding.SupplierTypeCode = supplier.SupplierTypeCode;
                    
                    var success = manager.Insert(bidding);
                    if (success)
                    {
                        foreach (var biddingDtl in dto.BiddingDtlDTO)
                        {
                            if(biddingDtl.Title==item.Title)
                            {
                                var model = new BiddingDtl();
                                model.BiddingDtlCode = manager.GetSysCodeValue("BiddingDtl");
                                model.BiddingCode = bidding.BiddingCode;
                                model.Title = biddingDtl.Title;
                                model.Money = item.Money;
                                model.remark = "";
                                model.CostCode = "102599";
                                model.CostBudgetSetCode = "100203";
                                model.isDeduct = "0";
                                var rows = manager.Db.Insertable<BiddingDtl>(model).ExecuteCommand();
                                if (rows <= 0)
                                {
                                    manager.Db.RollbackTran();
                                    res.ErrMsg = "招标计划明细插入失败，请重新操作";
                                    return Json(res);
                                }
                            }                            
                        }
                    }
                    else
                    {
                        manager.Db.RollbackTran();
                        res.ErrMsg = "招标计划插入失败，请重新操作";
                        return Json(res);
                    }
                }
                if(number.EndsWith(","))
                {
                    number = number.Substring(0, number.Length - 1);
                }
                 manager.Db.CommitTran();
                res.IsSuccess = true;
                res.ErrMsg = "";
                res.Code = 200;
                res.Data = number;
                return Json(res);
 
            }
            catch (Exception ex)
            {
                manager.Db.RollbackTran();
                logger.Error(ex);

                res.IsSuccess = false;
                res.ErrMsg = $"中标信息同步失败，错误信息：{ex.Message}";
                res.Code = 500;
                return Json(res);
            }
        }
        #endregion

        #endregion

    }
}
